#ifndef TEXTWINDOW_H
#define TEXTWINDOW_H



class TextWindow : public FXDialogBox
{
    FXDECLARE(TextWindow)
protected:
    FXText *text;
private:
    TextWindow()
    {}
    TextWindow(const TextWindow&);
public:
    enum{
        ID_CLOSE=FXDialogBox::ID_LAST,
        ID_LAST
    };
public:
    TextWindow(FXWindow *owner, const FXString& name, FXint nblines, FXint nbcols);
    virtual ~TextWindow();
	void setText(const FXchar*);
	void appendText(const FXchar* str);
	void scrollToLastLine(void);
	void setFont(FXFont* font);
	FXint getLength(void);
};

#endif
